@@ -2,4 +2,6 @@ from .__version__ import __version__
 
 from .actExecute import *
 from .actModuler import *
-from .actRunner import *
\ No newline at end of file
+from .actRunner import *
+from .actCreateSeg import *
+from .actUpdateSeg import *
\ No newline at end of file
